package VMOMI::DasConfigFaultDasConfigFaultReason;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
